@@ -35,7 +35,7 @@ LDAPObject_start_tls(LDAPObject *self, PyObject *args)
 	rc = ldap_start_tls_s(self->ldap, sctrls, cctrls);
 	LDAP_END_ALLOW_THREADS
 	if (rc != LDAP_SUCCESS) {
-		PyErr_SetString(LDAPError, ldap_err2string(rc));
+		PyErr_Format(LDAPError, "%s (%d)", ldap_err2string(rc), rc);
 		return NULL;
 	}
 	Py_RETURN_NONE;
